# PyXB -- Python W3C XML Schema Bindings

## End-of-life notice

The last release of PyXB was 1.2.6 dated 2017-09-03, with some patches
toward an optimistic PyXB 1.2.7 last made 2018-02-11.  No maintenance
has occured since then, and none is anticipated.

Per https://github.com/pabigot/pyxb/issues/100#issuecomment-1526932482
the last version of Python that PyXB works with at all reaches
end-of-life soon.

[PyXB-X](https://github.com/renalreg/PyXB-X) is a fork that may be
useful for people who have a dependence on PyXB and need further Python
releases.

2023-04-29
